BOWERDEPS="undefined"==typeof BOWERDEPS?{}:BOWERDEPS,function(){var n;n=function(){function n(){return["ui.router","ngAnimate","guanlecoja.ui","bbData"]}return n}(),angular.module("dbconfig",new n)}.call(this),function(){var n;n=function(){function n(n,o,t,i,a,g,c,l){_.mixin(n,c),console.log("dbconfig start"),n.settings=l.getSettingsGroup("DbConfig"),n.$watch("settings",function(){return l.save()},!0),n.getName=function(){return n.settings.name.value},n.loadConfig=function(){return console.log("dbconfig.loadConfig()"),i.get(e+n.getName()).then(function(e){return n.cfg=JSON.stringify(e.data),console.log("  name: "+n.getName()),console.log("  cfg: "+n.cfg)})},n.saveConfig=function(){return console.log("  name: "+n.getName()),console.log("dbconfig.saveConfig(): "+n.cfg),i.put(e+n.getName(),n.cfg)},n.loadConfig(),console.log("dbconfig end")}var e;return e="/dbconfig/api/config?name=",n}(),angular.module("dbconfig").controller("dbconfigController",["$scope","$state","$log","$http","config","dataService","resultsService","bbSettingsService",n])}.call(this),function(){var n;n=function(){function n(n,e,o,t){var i,a,g;a="dbconfig",o.addGroup({name:a,caption:"DbConfig",icon:"th-list",order:10}),i={group:a,caption:"DbConfig"},g={controller:a+"Controller",controllerAs:"w",templateUrl:"dbconfig/views/"+a+".html",name:a,url:"/"+a,data:i},e.plugins.dbconfig.show_menu&&n.state(g),t.addSettingsGroup({name:"DbConfig",caption:"DbConfig related settings",items:[{type:"text",name:"name",caption:"Config name",default_value:""}]})}return n}(),angular.module("dbconfig").config(["$stateProvider","config","glMenuServiceProvider","bbSettingsServiceProvider",n])}.call(this),angular.module("dbconfig").run(["$templateCache",function(n){n.put("dbconfig/views/dbconfig.html",'<div class="content"><div class="container"><h3>DbConfig debug view</h3><p>Name:&nbsp;<input type="text" ng-model="settings[&quot;name&quot;].value" label="Name:"/></p><p>Value:</p><textarea class="form-control" name="{{cfg}}" ng-model="cfg"></textarea><p></p><button ng-click="loadConfig()">Reload</button>&nbsp;<button ng-click="saveConfig()">Save</button></div></div>')}]);